@@ -73,7 +73,8 @@ export default class Start extends Command {
     }),
     multiuser: flags.boolean({
       char: 'm',
-      description: 'Starts CodeReady Workspaces in multi-user mode',
+      description: `Starts CodeReady Workspaces in multi-user mode.
+ 		                Note, this option is turned on by default.`,
       default: false
     }),
     tls: flags.boolean({
@@ -100,24 +101,10 @@ export default class Start extends Command {
       description: 'Installer type. If not set, default is olm for OpenShift >= 4.2, and operator for earlier versions.',
       options: ['olm', 'operator']
     }),
-    domain: string({
-      char: 'b',
-      description: `Domain of the Kubernetes cluster (e.g. example.k8s-cluster.com or <local-ip>.nip.io)
-                    This flag makes sense only for Kubernetes family infrastructures and will be autodetected for Minikube and MicroK8s in most cases.
-                    However, for Kubernetes cluster it is required to specify.
-                    Please note, that just setting this flag will not likely work out of the box.
-                    According changes should be done in Kubernetes cluster configuration as well.
-                    In case of Openshift, domain adjustment should be done on the cluster configuration level.`,
-      default: ''
-    }),
     debug: boolean({
       description: 'Enables the debug mode for CodeReady Workspaces server. To debug CodeReady Workspaces server from localhost use \'server:debug\' command.',
       default: false
     }),
-    'os-oauth': flags.boolean({
-      description: 'Enable use of OpenShift credentials to log into CodeReady Workspaces',
-      default: false
-    }),
     'che-operator-image': string({
       description: 'Container image of the operator. This parameter is used only when the installer is the operator',
       default: DEFAULT_CHE_OPERATOR_IMAGE
@@ -200,6 +187,7 @@ export default class Start extends Command {
 
     if (!flags.installer) {
       await this.setDefaultInstaller(flags)
+      cli.info(`› Installer type is set to: '${flags.installer}'`)
     }
 
     if (!flags.templates) {
@@ -257,7 +245,6 @@ export default class Start extends Command {
       flags['devfile-registry-url'] && ignoredFlags.push('--devfile-registry-url')
       flags['postgres-pvc-storage-class-name'] && ignoredFlags.push('--postgres-pvc-storage-class-name')
       flags['workspace-pvc-storage-class-name'] && ignoredFlags.push('--workspace-pvc-storage-class-name')
-      flags['os-oauth'] && ignoredFlags.push('--os-oauth')
       flags.tls && ignoredFlags.push('--tls')
       flags.cheimage && ignoredFlags.push('--cheimage')
       flags.debug && ignoredFlags.push('--debug')
@@ -283,14 +270,6 @@ export default class Start extends Command {
           this.error(`🛑 Current platform is ${flags.platform}. Helm installer is only available on top of Kubernetes flavor platform (including Minikube, Docker Desktop).`)
         }
       }
-      if (flags['os-oauth']) {
-        if (flags.platform !== 'openshift' && flags.platform !== 'minishift' && flags.platform !== 'crc') {
-          this.error(`You requested to enable OpenShift OAuth but the platform doesn\'t seem to be OpenShift. Platform is ${flags.platform}.`)
-        }
-        if (flags.installer !== 'operator' && flags.installer !== 'olm') {
-          this.error(`You requested to enable OpenShift OAuth but that's only possible when using the 'operator' or 'olm' as installer. The current installer is ${flags.installer}.`)
-        }
-      }
 
       if (flags.installer === 'olm' && flags.platform === 'minishift') {
         this.error(`🛑 The specified installer ${flags.installer} does not support Minishift`)
@@ -442,7 +421,6 @@ export default class Start extends Command {
       flags.installer = 'olm'
     } else {
       flags.installer = 'operator'
-      cli.info(`› Installer type is set to: '${flags.installer}'`)
     }
   }
 }
